/* $Workfile: OtxBrd.h $   $Revision: 23 $    $Modtime: 12/16/07 8:11p $  */
#ifndef OTX_BRD_H
#define OTX_BRD_H
/******************************************************************************

  @doc PublicHwApi OtxBrd

  Copyright (C) 1998 - 2007 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBrd | OTX Board Level Function Prototypes

  @contents2
  OtxBrd.h |

  @index func | OtxBrd

  @contents2
  OTX Board Level Functions - OtxBrdXXX() | Functions available for Board Level Operations

  @head3 OtxBrdXXX() Function Reference |

  @index func | OtxBrd

******************************************************************************/

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxDataD.h"
#include "OtxBrdD.h"

#ifdef __cplusplus
extern "C" {
#endif


/******************************************************************************

  @func
    Set the clock mode and the clock source for the OTX Board

  @comm
    All the highways on the OTX NIC Adapter are clocked with the same 8 kHz
    master framing clock. The source of the frame clock is set with this
    function.

    Basically, there are two types of clock modes, non-H.100 bus clocking (H.100
    bus is disconnected or H.100 bus is not available on board) and H.100 bus 
    clocking (H.100 bus is connected ). When H.100 bus is used, one board is 
    set as the Clock Master, other board(s) is set to the Clock Slave.
      
  @ex | non-H.100 bus clocking  
   // board is enabled before the clock source can be set 
   result = OtxDrvEnable(
              g_hPhysDevs.hBoardController,  
              OTX_TASK_SYNC, 
              5000L); 

   // Set Internal Oscillator as the clock source
   result = OtxBrdSetClocks(
              g_hPhysDevs.hBoardController, 
              OTX_CLOCK_MODE_LOCAL, 
              OTX_CLOCK_SOURCE_INTERNAL); 

  @ex | H.100 bus clocking   
   // two boards are enabled before the clock source can be set
   result = OtxDrvEnable(
              g_hPhysDevs.hBoardController0,  
              OTX_TASK_SYNC, 
              5000L); 
   result = OtxDrvEnable(
              g_hPhysDevs.hBoardController1,  
              OTX_TASK_SYNC, 
              5000L); 

   // Set Li#0 on board0 as the H.100 Clock Master
   result = OtxBrdSetClocks(
              g_hPhysDevs.hBoardController0, 
              OTX_CLOCK_MODE_H100, 
              OTX_CLOCK_SOURCE_LOCAL_0);

   // Set board1 as the H.100 Clock Slave (synchronize to the H.100 A-Clock 
   // sourced by board0)
   result = OtxBrdSetClocks(
              g_hPhysDevs.hBoardController1, 
              OTX_CLOCK_MODE_H100, 
              OTX_CLOCK_SOURCE_A_CLOCKS); 

  @xref
    <t OtxBrdClockModeE>
    <nl><t OtxBrdClockSourceE>

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBrdSetClocks(
  IN OTX_HANDLE           hBrdDevice,     // @parm Handle to Board device
  IN OtxBrdClockModeE     clkMode,        // @parm TSS Clock Mode (Master/Slave)
  IN OtxBrdClockSourceE   clkSource       // @parm Clock which the TSS uses to clock the highways
);


/******************************************************************************

  @func
    Set the PCM (Pulse Code Modulation) compression mode for the Codec. 
    
  @comm
    There are two standards (companssion modes), the U-Law standard 
    is used in North America and Japan (T1) while the A-Law standard is used 
    in most other countries, for example European countries (E1). 

  @ex | 
    // Get handles and set law for Codec devices #0 - #3
    for (i = 0; i < 4; i++) {
      OtxDrvOpenPhysicalDevice(
        g_hPhysDevs.hBoardController, 
        OTX_DEVICE_CODEC, 
        i, i, 
        g_hEventQueue, 
        &g_hPhysDevs.hCodec[i]
      );
 
      // Use G.711 U-law (North American) companded PCM data (8 bit samples) 
      // for T1 mode 
      OtxBrdCodecSetLaw(
        g_hPhysDevs.hCodec[i], 
        OTX_DATA_FORMAT_COMPAND8_U_LAW
      );
    }

  @xref
    <t OtxDataFormatE>

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBrdCodecSetLaw(
  IN OTX_HANDLE           hCodecDevice,   // @parm Handle to Codec device
  IN OtxDataFormatE       eLaw            // @parm U-law or A-law
);


/******************************************************************************

  @func
    Set a constant value to a timeslot on a highway

  @ex |
  // Get a handle to the Time-Space Switch (TSS) on the board
  result = OtxDrvOpenPhysicalDevice(
             g_hPhysDevs.hBoardController, 
             OTX_DEVICE_TSS, 
             0, 
             0, 
             g_hEventQueue, 
             &g_hPhysDevs.hTss); 
    
  // set constant value '10' on timeslot #5 of highway #2 
  result = OtxBrdTssConstByte(
             g_hPhysDevs.hTss,
             2, 
             5, 
             10);  

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBrdTssConstByte(
  IN OTX_HANDLE           hHwDevice,      // @parm Handle to TSS device
  IN OTX_UINT32           nHighWayOut,    // @parm highway number
  IN OTX_UINT32           nTimeSlotOut,   // @parm timeslot number
  IN OTX_UINT8            nConstValue     // @parm constant value in BYTE
);


#ifdef __cplusplus
}  // extern "C"
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2007


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif  // OTX_BRD_H
